@@ -4,7 +4,7 @@ package Spreadsheet::Examples;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-09'; # DATE
 our $DIST = 'Spreadsheet-Examples'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: A collection of various examples of spreadsheet files
@@ -21,7 +21,7 @@ Spreadsheet::Examples - A collection of various examples of spreadsheet files
 
 =head1 VERSION
 
-This document describes version 0.002 of Spreadsheet::Examples (from Perl distribution Spreadsheet-Examples), released on 2023-11-09.
+This document describes version 0.003 of Spreadsheet::Examples (from Perl distribution Spreadsheet-Examples), released on 2023-11-09.
 
 =head1 DESCRIPTION
 
@@ -37,14 +37,14 @@ The cells are numbers. Minimum formatting.
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/10sheet%2D10row%2D10col%2Eods">10sheet-10row-10col.ods</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/10sheet%2D10row%2D10col%2Eods">share/10sheet-10row-10col.ods</a><br />
 
 =end html
 
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/10sheet%2D10row%2D10col%2Exlsx">10sheet-10row-10col.xlsx</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/10sheet%2D10row%2D10col%2Exlsx">share/10sheet-10row-10col.xlsx</a><br />
 
 =end html
 
@@ -56,14 +56,14 @@ The cells are numbers. Minimum formatting.
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/10sheet%2D1000row%2D10col%2Eods">10sheet-1000row-10col.ods</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/10sheet%2D1000row%2D10col%2Eods">share/10sheet-1000row-10col.ods</a><br />
 
 =end html
 
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/10sheet%2D1000row%2D10col%2Exlsx">10sheet-1000row-10col.xlsx</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/10sheet%2D1000row%2D10col%2Exlsx">share/10sheet-1000row-10col.xlsx</a><br />
 
 =end html
 
@@ -74,14 +74,14 @@ Empty 10-sheet workbook.
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/10sheet%2Dempty%2Eods">10sheet-empty.ods</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/10sheet%2Dempty%2Eods">share/10sheet-empty.ods</a><br />
 
 =end html
 
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/10sheet%2Dempty%2Exlsx">10sheet-empty.xlsx</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/10sheet%2Dempty%2Exlsx">share/10sheet-empty.xlsx</a><br />
 
 =end html
 
@@ -92,14 +92,14 @@ Empty single-sheet workbook.
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/empty%2Eods">empty.ods</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/empty%2Eods">share/empty.ods</a><br />
 
 =end html
 
 
 =begin html
 
-<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.002/empty%2Exlsx">empty.xlsx</a><br />
+<a href="https://st.aticpan.org/source/PERLANCAR/Spreadsheet-Examples-0.003/share/empty%2Exlsx">share/empty.xlsx</a><br />
 
 =end html
 
